%define release_number %(echo $RELEASE_NUMBER)
%define version_number %(echo $SOURCES_VERSION)

Name:     squid
Version:  4.0.11
Release:  1%{?dist}
Summary:  The Squid proxy caching server
Packager: Django
Distribution: CentOS 7
# See CREDITS for breakdown of non GPLv2+ code
License:  GPLv2+ and (LGPLv2+ and MIT and BSD and Public Domain)
Group:    System Environment/Daemons
URL:      http://www.squid-cache.org
Source0:  http://www.squid-cache.org/Versions/v4/squid-%{version}.tar.xz
Source1:  http://www.squid-cache.org/Versions/v4/squid-%{version}.tar.xz.asc
Source2:  squid.service
Source3:  squid.logrotate
Source4:  squid.sysconfig
Source5:  squid.pam
Source6:  squid.nm
Source7:  squidshut.sh
Patch0:   pinger_off_v4.patch
Patch1:   suspendbyoptionsonly.patch
#Patch2:   assertion_FwdState.cc_serverConnection_eq_conn-trunk-t4-squid4.patch

Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: bash >= 2.0
Requires(pre): shadow-utils
Requires(preun): systemd
Requires(postun): systemd
Requires: systemd-units
Requires: libtool-ltdl
Requires: libecap
BuildRequires:  systemd-units
# squid_ldap_auth and other LDAP helpers require OpenLDAP
BuildRequires: openldap-devel
# squid_pam_auth requires PAM development libs
BuildRequires: pam-devel
# SSL support requires OpenSSL
BuildRequires: openssl-devel
# squid_kerb_aut requires Kerberos development libs
BuildRequires: krb5-devel
# squid_session_auth requires DB4
BuildRequires: db4-devel
# ESI support requires Expat & libxml2
BuildRequires: expat-devel libxml2-devel
# TPROXY requires libcap, and also increases security somewhat
BuildRequires: libcap-devel
# eCAP and some other need libltdl
BuildRequires: libtool libtool-ltdl-devel
# eCAP 1.0.0
BuildRequires: libecap-devel libecap
# Required to allow debug package auto creation
BuildRequires: redhat-rpm-config
# Required by couple external acl helpers
BuildRequires: libdb-devel
# Required for specific features
BuildRequires: libnetfilter_conntrack-devel
# Adding for future build use
BuildRequires: gnutls-devel

# Required to validate auto requires AutoReqProv: no
## aaaAutoReqProv: no

%description
Squid is a high-performance proxy caching server for Web clients,
supporting FTP, gopher, and HTTP data objects. Unlike traditional
caching software, Squid handles all requests in a single,
non-blocking, I/O-driven process. Squid keeps meta data and especially
hot objects cached in RAM, caches DNS lookups, supports non-blocking
DNS lookups, and implements negative caching of failed requests.

Squid consists of a main server program squid, a Domain Name System
lookup program (dnsserver), a program for retrieving FTP data
(ftpget), and some management and client tools.

%prep
%setup -q
%patch0
%patch1
#%patch2

%package helpers
Group: System Environment/Daemons
Summary: Squid helpers
Requires: %{name} = %{epoch}:%{version}-%{release}

%description helpers
The squid-helpers contains the external helpers.

%build
#was added due to new squid features that will be added soon
export CXXFLAGS="$RPM_OPT_FLAGS -fPIC"
export PERL=/usr/bin/perl

%configure \
  --exec_prefix=/usr \
  --libexecdir=%{_libdir}/squid \
  --localstatedir=/var \
  --datadir=%{_datadir}/squid \
  --sysconfdir=%{_sysconfdir}/squid \
  --with-logdir='$(localstatedir)/log/squid' \
  --with-pidfile='$(localstatedir)/run/squid.pid' \
  --disable-dependency-tracking \
  --enable-follow-x-forwarded-for \
  --enable-auth \
  --enable-auth-basic="DB,LDAP,NCSA,NIS,PAM,POP3,RADIUS,SASL,SMB,getpwnam,fake" \
  --enable-auth-ntlm="fake" \
  --enable-auth-digest="file,LDAP,eDirectory" \
  --enable-auth-negotiate="kerberos,wrapper" \
  --enable-external-acl-helpers="wbinfo_group,kerberos_ldap_group,LDAP_group,delayer,file_userip,SQL_session,unix_group,session,time_quota" \
  --enable-cache-digests \
  --enable-cachemgr-hostname=localhost \
  --enable-delay-pools \
  --enable-epoll \
  --enable-icap-client \
  --enable-ident-lookups \
  %ifnarch ppc64 ia64 x86_64 s390x
  --with-large-files \
  %endif
  --enable-linux-netfilter \
  --enable-removal-policies="heap,lru" \
  --enable-snmp \
  --enable-storeio="aufs,diskd,ufs,rock" \
  --enable-wccpv2 \
  --enable-esi \
  --enable-security-cert-generators  \
  --enable-security-cert-validators \
  --enable-icmp \
  --with-aio \
  --with-default-user="squid" \
  --with-filedescriptors=16384 \
  --with-dl \
  --with-openssl \
  --with-pthreads \
  --with-included-ltdl \
  --disable-arch-native \
  --enable-ecap \
  --without-nettle

make \
	DEFAULT_SWAP_DIR='$(localstatedir)/spool/squid' \
	%{?_smp_mflags}

#%install
%if %{?fedora}00%{?rhel} < 6
sed -i 's|password-auth|system-auth|' %{SOURCE5}
%endif
rm -rf $RPM_BUILD_ROOT
make \
	DESTDIR=$RPM_BUILD_ROOT \
	install
mkdir -p ${RPM_BUILD_ROOT}%{_unitdir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
mkdir -p $RPM_BUILD_ROOT/usr/libexec/squid
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/dispatcher.d
install -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/squid
install -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/squid
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/squid
install -m 644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/dispatcher.d/20-squid
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_unitdir}/squid.service
install -m 755 %{SOURCE7} $RPM_BUILD_ROOT%{_sbindir}/squidshut.sh

mkdir -p $RPM_BUILD_ROOT/var/log/squid
mkdir -p $RPM_BUILD_ROOT/var/spool/squid
#chmod 644 contrib/url-normalizer.pl contrib/rredir.* contrib/user-agents.pl
iconv -f ISO88591 -t UTF8 ChangeLog -o ChangeLog.tmp
mv -f ChangeLog.tmp ChangeLog

# Move the MIB definition to the proper place (and name)
mkdir -p $RPM_BUILD_ROOT/usr/share/snmp/mibs
mv $RPM_BUILD_ROOT/usr/share/squid/mib.txt $RPM_BUILD_ROOT/usr/share/snmp/mibs/SQUID-MIB.txt

# squid.conf.documented is documentation. We ship that in doc/
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/squid/squid.conf.documented

# remove unpackaged files from the buildroot
rm -f $RPM_BUILD_ROOT%{_bindir}/{RunAccel,RunCache}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc COPYING README CREDITS ChangeLog QUICKSTART src/squid.conf.documented
#%doc contrib/url-normalizer.pl contrib/rredir.* contrib/user-agents.pl

%attr(755,root,root) %dir %{_sysconfdir}/squid
%attr(755,root,root) %dir %{_libdir}/squid
%attr(750,squid,squid) %dir /var/log/squid
%attr(750,squid,squid) %dir /var/spool/squid

%config(noreplace) %attr(640,root,squid) %{_sysconfdir}/squid/squid.conf
%config(noreplace) %attr(644,root,squid) %{_sysconfdir}/squid/cachemgr.conf
%config(noreplace) %{_sysconfdir}/squid/mime.conf
%config(noreplace) %{_sysconfdir}/squid/errorpage.css
%config(noreplace) %{_sysconfdir}/sysconfig/squid
# These are not noreplace because they are just sample config files
%config %{_sysconfdir}/squid/squid.conf.default
%config %{_sysconfdir}/squid/mime.conf.default
%config %{_sysconfdir}/squid/errorpage.css.default
%config %{_sysconfdir}/squid/cachemgr.conf.default
%config(noreplace) %{_sysconfdir}/pam.d/squid
%config(noreplace) %{_sysconfdir}/logrotate.d/squid

%dir %{_datadir}/squid
%attr(-,root,root) %{_datadir}/squid/errors
%attr(755,root,root) %{_sysconfdir}/NetworkManager/dispatcher.d/20-squid
%attr(755,root,root) %{_sbindir}/squidshut.sh
%{_datadir}/squid/icons
%{_sbindir}/squid
%{_bindir}/squidclient
%{_bindir}/purge
%{_mandir}/man8/*
%{_mandir}/man1/*
%{_libdir}/squid/diskd
%{_libdir}/squid/log_file_daemon
%{_libdir}/squid/unlinkd
%attr(4755,root,root) %{_libdir}/squid/pinger

%{_datadir}/snmp/mibs/SQUID-MIB.txt
%{_unitdir}/squid.service

%files helpers
%{_libdir}/squid/basic_db_auth
%{_libdir}/squid/basic_getpwnam_auth
%{_libdir}/squid/basic_ldap_auth
%{_libdir}/squid/basic_ncsa_auth
%{_libdir}/squid/basic_nis_auth
%{_libdir}/squid/basic_pam_auth
%{_libdir}/squid/basic_pop3_auth
%{_libdir}/squid/basic_radius_auth
%{_libdir}/squid/basic_sasl_auth
%{_libdir}/squid/basic_smb_auth
%{_libdir}/squid/basic_smb_auth.sh
%{_libdir}/squid/basic_fake_auth
%{_libdir}/squid/cachemgr.cgi
%{_libdir}/squid/cert_tool
#%{_libdir}/squid/cert_valid.pl
%{_libdir}/squid/digest_file_auth
%{_libdir}/squid/digest_ldap_auth
%{_libdir}/squid/digest_edirectory_auth
%{_libdir}/squid/ext_kerberos_ldap_group_acl
%{_libdir}/squid/ext_wbinfo_group_acl
%{_libdir}/squid/helper-mux
%{_libdir}/squid/url_lfs_rewrite
%{_libdir}/squid/log_db_daemon
%{_libdir}/squid/negotiate_kerberos_auth
%{_libdir}/squid/negotiate_kerberos_auth_test
%{_libdir}/squid/negotiate_wrapper_auth
%{_libdir}/squid/ntlm_fake_auth
#%{_libdir}/squid/ntlm_smb_lm_auth
#%{_libdir}/squid/ssl_crtd
%{_libdir}/squid/storeid_file_rewrite
%{_libdir}/squid/url_fake_rewrite
%{_libdir}/squid/url_fake_rewrite.sh
%{_libdir}/squid/ext_delayer_acl
%{_libdir}/squid/ext_file_userip_acl
%{_libdir}/squid/ext_ldap_group_acl
%{_libdir}/squid/ext_session_acl
%{_libdir}/squid/ext_sql_session_acl
%{_libdir}/squid/ext_time_quota_acl
%{_libdir}/squid/ext_unix_group_acl

%{_libdir}/squid/helper-mux
%{_libdir}/squid/security_fake_certverify
%{_libdir}/squid/security_file_certgen
%{_libdir}/squid/url_lfs_rewrite

#error: File not found: /home/rpm/rpmbuild/BUILDROOT/squid-4.0.5-1.el7.centos.x86_64/usr/lib64/squid/cert_valid.pl
#error: File not found: /home/rpm/rpmbuild/BUILDROOT/squid-4.0.5-1.el7.centos.x86_64/usr/lib64/squid/ntlm_smb_lm_auth
#error: File not found: /home/rpm/rpmbuild/BUILDROOT/squid-4.0.5-1.el7.centos.x86_64/usr/lib64/squid/ssl_crtd


%pre
if ! getent group squid >/dev/null 2>&1; then
  /usr/sbin/groupadd -g 23 squid
fi

if ! getent passwd squid >/dev/null 2>&1 ; then
  /usr/sbin/useradd -g 23 -u 23 -d /var/spool/squid -r -s /sbin/nologin squid >/dev/null 2>&1 || exit 1 
fi

for i in /var/log/squid /var/spool/squid ; do
        if [ -d $i ] ; then
                for adir in `find $i -maxdepth 0 \! -user squid`; do
                        chown -R squid:squid $adir
                done
        fi
done

exit 0

%post
echo "squid.conf.documented is at /usr/share/squid-%{version}/squid.conf.documented"
%systemd_post squid.service

%preun
%systemd_preun squid.service

%postun
%systemd_postun_with_restart squid.service

%postun helpers
%triggerin -- samba-common
if ! getent group wbpriv >/dev/null 2>&1 ; then
  /usr/sbin/groupadd -g 88 wbpriv >/dev/null 2>&1 || :
fi
/usr/sbin/usermod -a -G wbpriv squid >/dev/null 2>&1 || \
    chgrp squid /var/lib/samba/winbindd_privileged >/dev/null 2>&1 || :
    chmod 750 /var/lib/samba/winbindd_privileged  >/dev/null 2>&1 || :

%changelog
* Wed Jun 29 2016 Django <django@mailserver.guru> - 4.0.11-1
- Changes to squid-4.0.11:
  Bug 4517: error: comparison between signed and unsigned integer
  Bug 4492: chunked parser needs to accept BWS after chunk size
  HTTP/1.1: allow chunking the last HTTP response on a connection
  HTTP/1.1: unfold mime header blocks
  TLS: fast SNI peek
  TLS: check for SSL_CIPHER_get_id() support required in adjustSSL()
  TLS: never enable OPENSSL_HELLO_OVERWRITE_HACK automatically
  squidclient: improve shell-escape support in -H option
  Do not allow low-level debugging to hide important/critical messages
  Replace new/delete operators using modern C++ rules
  Remove ie_refresh configuration option
  Deprecating SMB LanMan helpers
  Mark refresh-waiting transactions with REFRESH
  ... and some code cleanup and polishing

* Fri May 06 2016 Django <django@mailserver.guru> - 4.0.10-1
- Changes to squid-4.0.10:
  Accumulate fewer unknown-size responses to avoid overwhelming disks.
  Fix shared memory corruption when storing multi-slot (>32KB) shm misses.
  ... and some documentation and code cleanup

* Wed Apr 20 2016 Django <django@mailserver.guru> - 4.0.9-1
- Changes to squid-4.0.9:
  Bug 4405: assertion failed: comm.cc:554: "Comm::IsConnOpen(conn)"
  Add a new error page token for unquoted external ACL messages.
  Stop parsing response prefix after discovering an "HTTP/0.9" response.
  ... and some documentation updates
  ... and some code polishing

* Sat Apr 02 2016 Django <django@mailserver.guru> - 4.0.8-1
- Changes to squid-4.0.8:
  Bug 4459: FHS compliance: move netdb.state and ssl_db to /var/cache/squid
  Bug 4458: Behaviour change with external ACL arguments
  Bug 4450: wait() related cleanup
  Bug 4438: SIGSEGV in memFreeString() destructing SBuf globals on shutdown/restart
  Bug 4312: Support disabling collapsed forwarding SMP cooperation
  Bug 3826: SMP compatibility with systemd and --foreground option
  Bug 1979: Add ACL-driven server_pconn_for_nonretriable squid.conf directive
  Bug 7 (partial): Update cached entries on 304 responses
  Add reply_header_add directive
  HTTP/1.1: Do not prohibit updating Last-Modified on 304 responses
  Fix memory leaks of lastAclData and AccessLogentry::url
  Fix clang -Winconsistent-missing-override warning
  Tests: update test suite for GnuTLS
  ... and some documentation updates
  ... and some code cleanup and polishing

* Tue Feb 23 2016 Django <django@mailserver.guru> - 4.0.7-1
- Changes to squid-4.0.7:
  Regression Fix: external_acl parameters separated by %20 instead of space
  Bug 4432: assertion failed: store.cc:1919: "isEmpty()"
  Bug 4111: leave_suid() does not properly handle error codes returned by setuid
  Fix propagation of response status line parsing error details
  Fix memory leak when the cache of sslcrtvalidator_program is disabled via ttl=0
  ... and some code SourceLayout project cleaning

* Tue Feb 16 2016 Django <django@mailserver.guru> - 4.0.6-1
- Changes to squid-4.0.6:
  Regression Bug 4436: Fix DEFAULT_SSL_CRTD
  Fix "dial: Ssl::PeerConnector::sslCrtvdHandleReply threw exception: callback != NULL"
  ... and some documentation updates

* Tue Feb 09 2016 Django <django@mailserver.guru> - 4.0.5-1
- Changes to squid-4.0.5:
  Regression Bug 4429: http(s)_port options= error message missing characters
  Regression Bug 4410: 4.0.4 compile error in basic_ncsa_auth
  Regression Bug 4403: helper compile errors after 4.0.4 rev.14454
  Regression Bug 4401: compile error on Solaris
  Regression Fix: TLS/SSL flags parsing
  Regression Fix: cert validadator always disabled in 4.x
  Regression Fix: Name-only note ACL stopped matching after 4.0.4 rev.14465 (note -m)
  Regression Fix: external_acl problems after 4.0.1 rev.14351
  Bug 4409 (partial): compile error when two Heimdal libraries are installed
  Bug 4005: Dynamic certificate cache exceeds dynamic_cert_mem_cache_size
  SMP: Fix cleanup of a shared memory segment in an unusual configuration
  SSL-Bump: Fix step3 splicing.
  Add connections_encrypted ACL
  Make %<a and %<p details available to [eCAP] RESPMOD services
  Rename cert_valid.pl to security_fake_certverify
  Rename ssl_crtd helper to security_file_certgen
  ... and a lot of code SourceLayout project cleaning
  ... and some documentation updates

* Wed Jan 06 2016 Django <django@mailserver.guru> - 4.0.4-1
- Changes to squid-4.0.4:
  Regression Bug 4393: compile fails on OS X
  Bug 4392: assertion CbcPointer.h:159: 'c' via tunnelServerClosed or tunnelClientClosed
  Support use of Kerberos credentials cache instead of keytab
  Support logging of TLS Cryptography Parameters
  Support substring matching in Note ACL
  ... and some code cleanup and polishing

* Sat Nov 28 2015 Django <django@mailserver.guru> - 4.0.3-1
- Changes to squid-4.0.3i:
  Bug 4372: missing template files
  Bug 4371: compile errors: no such file or directory: DiskIO/*/*DiskIOModule.o
  Bug 4368: A simpler and more robust HTTP request line parser
  Fix compile erorr on clang undefined reference to '__atomic_load_8'
  ext_kerberos_ldap_group_acl: Add missing workarounds for Heimdal Kerberos
  ext_ldap_group_acl: Allow unlimited LDAP search filter
  ext_unix_group_acl: Support -r parameter to strip @REALM from usernames
  ... and much code cleanup and polishing

* Sun Nov 01 2015 Django <django@mailserver.guru> - 4.0.2-1
- Changes to squid-4.0.2:
  Regression Bug 4351: compile errors when authentication modules disabled
  Regression fix: HTTP/1.1 Transfer-Encoding:chunked parsing
  Bug 4359: assertion failure 'Comm::IsConnOpen(conn)' within ConnStateData::requestTimeout
  Bug 4356: segmentation fault using proxy_auth ACL
  Bug 4352: compile errors in OS X 10.11
  Bug 4021: ext_user_regex does exact match
  Bug 3574: avoid crashes, prohibit reconfiguration during shutdown
  Support re-assigning delay pools based on HTTP reply details

* Sat Oct 31 2015 Django <django@mailserver.guru> - 4.0.1-1
- Initial build for CentOS 7
